import react, {
  cloneElement,
  JSXElementConstructor,
  ReactElement,
  useEffect,
  useRef,
  useState,
} from 'react';
import TileSet from './TileSet';
import { Point, Rectangle, TileKeyObject } from './types';
import { CoordinateSystem } from './LiveMap';
import useViewport from './use-viewport';

export interface TiledLayerProperties {
  /**
   * A key identifying the top left tile
   */
  keyObject: TileKeyObject;
  /**
   * The translation to apply.
   */
  shift: Point;
  /**
   * The zoom to apply. If equal to 256 (the tile size), the layer is considered active and should add tiles which are in its viewport
   */
  zoom: number;
  /**
   * The coordinate system
   */
  coordinateSystem: CoordinateSystem;
  /**
   *
   */
  viewPort?: Rectangle;
}

/**
 *
 * @param props
 * @returns A layer of tiles.
 * This component wraps a `<TileSet>` in an SVG `<g>` element taking care of the scale and translation.
 *
 */
export const TiledLayer: react.FC<TiledLayerProperties> = (
  props: TiledLayerProperties
) => {
  console.log(
    `Rendering TiledLayer, zoom: ${props.zoom}, viewPort: ${JSON.stringify(
      props.viewPort
    )}`
  );
  return (
    <>
      <g
        transform={`scale(${props.zoom}) translate(${props.shift.x}, ${props.shift.y})`}
      >
        <TileSet
          keyObject={{
            provider: props.keyObject.provider,
            zoomLevel: props.keyObject.zoomLevel,
            x: 0,
            y: 0,
          }}
          viewPort={props.viewPort}
        />
      </g>
    </>
  );
};

export default TiledLayer;
