import react, { startTransition, useEffect, useState } from 'react';
import { lon2tile, lat2tile } from '../../lib/geo';
import dispatch from '../../workers/dispatcher-main';
import { TileKeyObject, Rectangle, Point, geoPoint } from './types';

import css from './Trkseg.module.css';
import { ReactComponent as Start } from '../../icons/flag-start-b-svgrepo-com.svg';
import { ReactComponent as Finish } from '../../icons/flag-finish-b-o-svgrepo-com.svg';
import Marker from './Marker';

export interface TrksegProperties {
  id: string;
  keyObject: TileKeyObject;
  zoom: number;
  viewPort: Rectangle;
}

export const Trkseg: react.FC<TrksegProperties> = (props: TrksegProperties) => {
  const [trkseg, setTrkseg] = useState<any>([]);
  useEffect(() => {
    const getTrkseg = async () => {
      const trk = await dispatch({
        action: 'getTrkseg',
        params: {
          id: props.id,
        },
      });
      console.log(`<Trkseg>, gpx: ${JSON.stringify(trk)}`);
      startTransition(() => setTrkseg(trk));
    };
    getTrkseg();
  }, [props.id]);

  const d = trkseg
    .slice(1)
    .reduce((previous: string, current: any, index: number) => {
      const action = index === 0 ? 'M' : index === 1 ? 'L' : '';
      const trkpt = current.doc.doc;
      return `${previous} ${action} ${
        (lon2tile(trkpt.$.lon, props.keyObject.zoomLevel) - props.keyObject.x) *
        256
      }, ${
        (lat2tile(trkpt.$.lat, props.keyObject.zoomLevel) - props.keyObject.y) *
        256
      }`;
    }, '');

  return (
    <>
      {trkseg[1] !== undefined ? (
        <>
          <Marker
            coordinates={trkseg[1].doc.doc.$ as geoPoint}
            key='start'
            keyObject={props.keyObject}
            icon={
              <g
                className={css.start}
                transform=' scale(.5) translate(-50, -100)'
              >
                <Start />
              </g>
            }
            viewPort={props.viewPort}
            zoom={props.zoom}
          />

          <path d={d} pointerEvents='none' className={css.track} />
          <Marker
            coordinates={trkseg.at(-1).doc.doc.$ as geoPoint}
            key='finish'
            keyObject={props.keyObject}
            icon={
              <g
                className={css.finish}
                transform=' scale(.5) translate(-50, -100)'
              >
                <Finish />
              </g>
            }
            viewPort={props.viewPort}
            zoom={props.zoom}
          />
        </>
      ) : null}
    </>
  );
};

export default Trkseg;
