import { putNewTrk } from './trk';

declare global {
  var db: any;
  var dbReady: boolean;
}

const originalDb = globalThis.db;
const originalDateNow = globalThis.Date.now;

describe('The trk module', () => {
  beforeEach(() => {
    globalThis.db = { put: jest.fn() };
    globalThis.Date.now = () => 0;
  });
  afterEach(() => {
    globalThis.db = originalDb;
    globalThis.Date.now = originalDateNow;
  });
  test('db.put() a new trk when required', async () => {
    putNewTrk({ gpx: 1, trk: 2 });
    await expect(globalThis.db.put).toBeCalledWith({
      _id: 'gpx/0000000000000001/3trk/000002',
      _rev: undefined,
      doc: {
        cmt: undefined,
        desc: undefined,
        extensions: undefined,
        link: undefined,
        name: undefined,
        number: 0,
        src: undefined,
        trkseg: undefined,
        type: undefined,
      },
      type: 'trk',
    });
  });
  test('db.put() generates an id for the trk if needed', async () => {
    const id = await putNewTrk({ gpx: 2 });
    expect(id).toEqual({ gpx: 2, trk: 0});
  });
  test('db.put() generates ids for both gpx and trk if needed', async () => {
    const id = await putNewTrk();
    expect(id).toEqual({ gpx: 4320000000000000, trk: 0});
  });
});
