import { getWorker } from './get-worker';

declare global {
  var dispatcherQueue: { index: number; queue: Map<number, any> };
}

export var worker: any;

export const init = () => {
  globalThis.dispatcherQueue = { index: 0, queue: new Map() };

  worker = getWorker();

  console.log(`worker: ${worker}`);

  worker.onmessage = (event: any) => {
    const { id, payload } = event.data;
    dispatcherQueue.queue.get(id)(null, payload);
    dispatcherQueue.queue.delete(id);
  };
};

const dispatch = (
  payload: any,
  callBack?: (error: any, result: any) => void
) => {
  if (worker === undefined) {
    init();
  }
  if (callBack === undefined) {
    /** If a callback function is not provided, return a promise */
    return new Promise((resolve, reject) => {
      dispatch(payload, (error, result) => {
        if (error) {
          reject(error);
        } else {
          resolve(result);
        }
      });
    });
  }
  /** Otherwise, use the callback function */
  dispatcherQueue.queue.set(dispatcherQueue.index, callBack);
  const message = {
    id: dispatcherQueue.index++,
    payload: payload,
  };
  worker.postMessage(message);
};

export default dispatch;
